Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(503)

Unified Diff: media/filters/decrypting_video_decoder.h

Issue 1423163004: media: Replace DecryptorReadyCB with CdmReadyCB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix android Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/filters/decrypting_video_decoder.h
diff --git a/media/filters/decrypting_video_decoder.h b/media/filters/decrypting_video_decoder.h
index 80b3b814bf5a4f904897c635879ecf5030dcbccf..1ac97b81f32d04455f27549af2997554252823a0 100644
--- a/media/filters/decrypting_video_decoder.h
+++ b/media/filters/decrypting_video_decoder.h
@@ -7,6 +7,7 @@
#include "base/callback.h"
#include "base/memory/weak_ptr.h"
+#include "media/base/cdm_context.h"
#include "media/base/decryptor.h"
#include "media/base/video_decoder.h"
#include "media/base/video_decoder_config.h"
@@ -30,7 +31,7 @@ class MEDIA_EXPORT DecryptingVideoDecoder : public VideoDecoder {
DecryptingVideoDecoder(
const scoped_refptr<base::SingleThreadTaskRunner>& task_runner,
const scoped_refptr<MediaLog>& media_log,
- const SetDecryptorReadyCB& set_decryptor_ready_cb,
+ const SetCdmReadyCB& set_cdm_ready_cb,
const base::Closure& waiting_for_decryption_key_cb);
~DecryptingVideoDecoder() override;
@@ -61,10 +62,9 @@ class MEDIA_EXPORT DecryptingVideoDecoder : public VideoDecoder {
kError
};
- // Callback for DecryptorHost::RequestDecryptor(). |decryptor_attached_cb| is
- // called when the decryptor has been completely attached to the pipeline.
- void SetDecryptor(Decryptor* decryptor,
- const DecryptorAttachedCB& decryptor_attached_cb);
+ // Callback to set CDM. |cdm_attached_cb| is called when the decryptor in the
+ // CDM has been completely attached to the pipeline.
+ void SetCdm(CdmContext* cdm_context, const CdmAttachedCB& cdm_attached_cb);
// Callback for Decryptor::InitializeVideoDecoder() during initialization.
void FinishInitialization(bool success);
@@ -97,8 +97,8 @@ class MEDIA_EXPORT DecryptingVideoDecoder : public VideoDecoder {
VideoDecoderConfig config_;
- // Callback to request/cancel decryptor creation notification.
- SetDecryptorReadyCB set_decryptor_ready_cb_;
+ // Callback to request/cancel CDM ready notification.
+ SetCdmReadyCB set_cdm_ready_cb_;
Decryptor* decryptor_;

Powered by Google App Engine
This is Rietveld 408576698